=========
Resources
=========

API and Server State
====================

.. toctree::
   :maxdepth: 1

   root
   server-info


Default Reviewers
=================

.. toctree::
   :maxdepth: 1

   default-reviewer-list
   default-reviewer


Diffs
=====

.. toctree::
   :maxdepth: 1

   diff-context
   diff-list
   diff
   diff-file-attachment-list
   diff-file-attachment
   original-file
   patched-file


Extensions
==========

.. toctree::
   :maxdepth: 1

   extension-list
   extension


Hosting Services
================

.. toctree::
   :maxdepth: 1

   hosting-service-list
   hosting-service
   hosting-service-account-list
   hosting-service-account
   remote-repository-list
   remote-repository


OAuth2
======

.. toctree::
   :maxdepth: 1

   oauth-application-list
   oauth-application
   oauth-token-list
   oauth-token


Repositories
============

.. toctree::
   :maxdepth: 1

   repository-branches
   repository-commits
   repository-info
   repository-list
   repository


Review Groups
=============

.. toctree::
   :maxdepth: 1

   review-group-list
   review-group
   review-group-user-list
   review-group-user


Review Requests
===============

.. toctree::
   :maxdepth: 1

   change-list
   change
   file-attachment-list
   file-attachment
   file-attachment-comment-list
   file-diff-list
   file-diff
   file-diff-comment-list
   review-request-list
   review-request
   review-request-last-update
   screenshot-list
   screenshot
   screenshot-comment-list


Review Request Drafts
=====================

.. toctree::
   :maxdepth: 1

   draft-diff-list
   draft-diff
   draft-file-diff-list
   draft-file-diff
   draft-file-attachment-list
   draft-file-attachment
   draft-original-file
   draft-patched-file
   draft-screenshot-list
   draft-screenshot
   review-request-draft


Reviews
=======

.. toctree::
   :maxdepth: 1

   review-list
   review
   review-draft
   review-diff-comment-list
   review-diff-comment
   review-file-attachment-comment-list
   review-file-attachment-comment
   review-general-comment-list
   review-general-comment
   review-screenshot-comment-list
   review-screenshot-comment


Review Replies
==============

.. toctree::
   :maxdepth: 1

   review-reply-draft
   review-reply-list
   review-reply
   review-reply-diff-comment-list
   review-reply-diff-comment
   review-reply-file-attachment-comment-list
   review-reply-file-attachment-comment
   review-reply-general-comment-list
   review-reply-general-comment
   review-reply-screenshot-comment-list
   review-reply-screenshot-comment


Search
======

.. toctree::
   :maxdepth: 1

   search


.. _webapi2.0-status-update-resources:

Status Updates
==============

.. toctree::
   :maxdepth: 1

   status-update-list
   status-update


Users
=====

.. toctree::
   :maxdepth: 1

   api-token-list
   api-token
   archived-review-request-list
   archived-review-request
   muted-review-request-list
   muted-review-request
   session
   user-list
   user
   user-file-attachment-list
   user-file-attachment
   watched-review-group-list
   watched-review-group
   watched-review-request-list
   watched-review-request
   watched


Validation
==========

.. toctree::
   :maxdepth: 1

   validation
   validate-diff


WebHooks
========

.. toctree::
   :maxdepth: 1

   web-hook-list
   web-hook
